import { EditorView } from '@codemirror/view';
import { HighlightStyle, tags } from '@codemirror/highlight';

const draculaTheme = EditorView.theme({
    '&': {
        color: '#F8F8F2',
        backgroundColor: '#282A36',
        '& ::selection': { backgroundColor: '#44475A' },
        caretColor: '#F8F8F2',
    },
    '&.cm-focused .cm-cursor': { borderLeftColor: '#F8F8F2' },
    '&.cm-focused .cm-selectionBackground, .cm-selectionBackground': { backgroundColor: '#44475A' },
    '.cm-panels': { backgroundColor: '#343746', color: '#F8F8F2' },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        backgroundColor: '#343746',
        outline: `1px solid #191A21`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: '#44475A'
    },
    '.cm-activeLine': { backgroundColor: '#44475A' },
    '.cm-selectionMatch': { backgroundColor: '#44475A' },
    '.cm-matchingBracket, .cm-nonmatchingBracket': {
        backgroundColor: '#FF5555',
        outline: 'none'
    },
    '.cm-gutters': {
        backgroundColor: '#282A36',
        color: '#F8F8F2',
        border: 'none'
    },
    '.cm-lineNumbers, .cm-gutterElement': { color: 'inherit' },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#F8F8F2'
    },
    '.cm-tooltip': {
        border: '1px solid #191A21',
        backgroundColor: '#343746'
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: '#44475A',
            color: '#F8F8F2'
        }
    }
}, { dark: true });
const draculaHighlightStyle = HighlightStyle.define([
    // const, let, function, if
    { tag: tags.keyword, color: '#FF79C6' },
    // document
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: '#BD93F9' },
    // getElementById
    { tag: [tags.propertyName], color: '#50FA7B' },
    // "string"
    { tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)], color: '#F1FA8C' },
    // render
    { tag: [tags.function(tags.variableName), tags.labelName], color: '#50FA7B' },
    // ???
    { tag: [tags.color, tags.constant(tags.name), tags.standard(tags.name)], color: '#BD93F9' },
    // btn, count, fn render()
    { tag: [tags.definition(tags.name), tags.separator], color: '#BD93F9' },
    { tag: [tags.className], color: '#8BE9FD' },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: '#BD93F9' },
    { tag: [tags.typeName], color: '#8BE9FD', fontStyle: 'italic' },
    { tag: [tags.operator, tags.operatorKeyword], color: '#FF79C6' },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: '#F1FA8C' },
    { tag: [tags.meta, tags.comment], color: '#6272A4' },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: '#BD93F9' },
    { tag: [tags.atom, tags.bool, tags.special(tags.variableName)], color: '#BD93F9' },
    { tag: tags.invalid, color: '#FF5555' },
]);
const dracula = [
    draculaTheme,
    draculaHighlightStyle,
];

export { dracula, draculaHighlightStyle, draculaTheme };
