import { EditorView } from '@codemirror/view';
import { HighlightStyle, tags } from '@codemirror/highlight';

const githubDarkTheme = EditorView.theme({
    '&': {
        color: '#d1d5da',
        backgroundColor: '#24292e',
        '& ::selection': { backgroundColor: '#3392FF44' },
        caretColor: '#c8e1ff',
    },
    '&.cm-focused .cm-cursor': { borderLeftColor: '#c8e1ff' },
    '&.cm-focused .cm-selectionBackground, .cm-selectionBackground': { backgroundColor: '#3392FF44' },
    '.cm-panels': { backgroundColor: '#2f363d', color: '#d1d5da' },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        backgroundColor: '#2f363d',
        outline: `1px solid #1b1f23`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: '#3392FF44'
    },
    '.cm-activeLine': { backgroundColor: '#3392FF44' },
    '.cm-selectionMatch': { backgroundColor: '#3392FF44' },
    '.cm-matchingBracket, .cm-nonmatchingBracket': {
        backgroundColor: '#f97583',
        outline: 'none'
    },
    '.cm-gutters': {
        backgroundColor: '#24292e',
        color: '#d1d5da',
        border: 'none'
    },
    '.cm-lineNumbers, .cm-gutterElement': { color: 'inherit' },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#d1d5da'
    },
    '.cm-tooltip': {
        border: '1px solid #1b1f23',
        backgroundColor: '#2f363d'
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: '#3392FF44',
            color: '#d1d5da'
        }
    }
}, { dark: true });
const githubDarkHighlightStyle = HighlightStyle.define([
    // const, let, function, if
    { tag: tags.keyword, color: '#f97583' },
    // document
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: '#e1e4e8' },
    // getElementById
    { tag: [tags.propertyName], color: '#b392f0' },
    // "string"
    { tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)], color: '#9ecbff' },
    // render
    { tag: [tags.function(tags.variableName), tags.labelName], color: '#b392f0' },
    // ???
    { tag: [tags.color, tags.constant(tags.name), tags.standard(tags.name)], color: '#79b8ff' },
    // btn, count, fn render()
    { tag: [tags.definition(tags.name), tags.separator], color: '#e1e4e8' },
    { tag: [tags.className], color: '#b392f0' },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: '#79b8ff' },
    { tag: [tags.typeName], color: '#79b8ff', fontStyle: '' },
    { tag: [tags.operator, tags.operatorKeyword], color: '#f97583' },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: '#dbedff' },
    { tag: [tags.meta, tags.comment], color: '#6a737d' },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: '#79b8ff' },
    { tag: [tags.atom, tags.bool, tags.special(tags.variableName)], color: '#e1e4e8' },
    { tag: tags.invalid, color: '#f97583' },
]);
const githubDark = [
    githubDarkTheme,
    githubDarkHighlightStyle,
];

export { githubDark, githubDarkHighlightStyle, githubDarkTheme };
