import { EditorView } from '@codemirror/view';
import { HighlightStyle, tags } from '@codemirror/highlight';

const githubLightTheme = EditorView.theme({
    '&': {
        color: '#444d56',
        backgroundColor: '#fff',
        '& ::selection': { backgroundColor: '#0366d625' },
        caretColor: '#044289',
    },
    '&.cm-focused .cm-cursor': { borderLeftColor: '#044289' },
    '&.cm-focused .cm-selectionBackground, .cm-selectionBackground': { backgroundColor: '#0366d625' },
    '.cm-panels': { backgroundColor: '#fafbfc', color: '#444d56' },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        backgroundColor: '#fafbfc',
        outline: `1px solid #e1e4e8`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: '#0366d625'
    },
    '.cm-activeLine': { backgroundColor: '#0366d625' },
    '.cm-selectionMatch': { backgroundColor: '#0366d625' },
    '.cm-matchingBracket, .cm-nonmatchingBracket': {
        backgroundColor: '#cb2431',
        outline: 'none'
    },
    '.cm-gutters': {
        backgroundColor: '#fff',
        color: '#444d56',
        border: 'none'
    },
    '.cm-lineNumbers, .cm-gutterElement': { color: 'inherit' },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#444d56'
    },
    '.cm-tooltip': {
        border: '1px solid #e1e4e8',
        backgroundColor: '#fafbfc'
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: '#0366d625',
            color: '#444d56'
        }
    }
}, { dark: false });
const githubLightHighlightStyle = HighlightStyle.define([
    // const, let, function, if
    { tag: tags.keyword, color: '#d73a49' },
    // document
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: '#24292e' },
    // getElementById
    { tag: [tags.propertyName], color: '#6f42c1' },
    // "string"
    { tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)], color: '#032f62' },
    // render
    { tag: [tags.function(tags.variableName), tags.labelName], color: '#6f42c1' },
    // ???
    { tag: [tags.color, tags.constant(tags.name), tags.standard(tags.name)], color: '#005cc5' },
    // btn, count, fn render()
    { tag: [tags.definition(tags.name), tags.separator], color: '#24292e' },
    { tag: [tags.className], color: '#6f42c1' },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: '#005cc5' },
    { tag: [tags.typeName], color: '#005cc5', fontStyle: '' },
    { tag: [tags.operator, tags.operatorKeyword], color: '#d73a49' },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: '#032f62' },
    { tag: [tags.meta, tags.comment], color: '#6a737d' },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: '#005cc5' },
    { tag: [tags.atom, tags.bool, tags.special(tags.variableName)], color: '#24292e' },
    { tag: tags.invalid, color: '#cb2431' },
]);
const githubLight = [
    githubLightTheme,
    githubLightHighlightStyle,
];

export { githubLight, githubLightHighlightStyle, githubLightTheme };
