import { EditorView } from '@codemirror/view';
import { HighlightStyle, tags } from '@codemirror/highlight';

const materialDarkTheme = EditorView.theme({
    '&': {
        color: '#EEFFFF',
        backgroundColor: '#263238',
        '& ::selection': { backgroundColor: '#80CBC420' },
        caretColor: '#FFCC00',
    },
    '&.cm-focused .cm-cursor': { borderLeftColor: '#FFCC00' },
    '&.cm-focused .cm-selectionBackground, .cm-selectionBackground': { backgroundColor: '#80CBC420' },
    '.cm-panels': { backgroundColor: '#263238', color: '#EEFFFF' },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        backgroundColor: '#263238',
        outline: `1px solid #FFFFFF10`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: '#80CBC420'
    },
    '.cm-activeLine': { backgroundColor: '#80CBC420' },
    '.cm-selectionMatch': { backgroundColor: '#80CBC420' },
    '.cm-matchingBracket, .cm-nonmatchingBracket': {
        backgroundColor: '#f0717870',
        outline: 'none'
    },
    '.cm-gutters': {
        backgroundColor: '#263238',
        color: '#EEFFFF',
        border: 'none'
    },
    '.cm-lineNumbers, .cm-gutterElement': { color: 'inherit' },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#EEFFFF'
    },
    '.cm-tooltip': {
        border: '1px solid #FFFFFF10',
        backgroundColor: '#263238'
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: '#80CBC420',
            color: '#EEFFFF'
        }
    }
}, { dark: true });
const materialDarkHighlightStyle = HighlightStyle.define([
    // const, let, function, if
    { tag: tags.keyword, color: '#89DDFF' },
    // document
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: '#EEFFFF' },
    // getElementById
    { tag: [tags.propertyName], color: '#82AAFF' },
    // "string"
    { tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)], color: '#C3E88D' },
    // render
    { tag: [tags.function(tags.variableName), tags.labelName], color: '#82AAFF' },
    // ???
    { tag: [tags.color, tags.constant(tags.name), tags.standard(tags.name)], color: '#89DDFF' },
    // btn, count, fn render()
    { tag: [tags.definition(tags.name), tags.separator], color: '#EEFFFF' },
    { tag: [tags.className], color: '#FFCB6B' },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: '#F78C6C' },
    { tag: [tags.typeName], color: '#FFCB6B', fontStyle: '' },
    { tag: [tags.operator, tags.operatorKeyword], color: '#89DDFF' },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: '#C3E88D' },
    { tag: [tags.meta, tags.comment], color: '#546E7A' },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: '#89DDFF' },
    { tag: [tags.atom, tags.bool, tags.special(tags.variableName)], color: '#EEFFFF' },
    { tag: tags.invalid, color: '#f0717870' },
]);
const materialDark = [
    materialDarkTheme,
    materialDarkHighlightStyle,
];

export { materialDark, materialDarkHighlightStyle, materialDarkTheme };
