import { EditorView } from '@codemirror/view';
import { HighlightStyle, tags } from '@codemirror/highlight';

const solarizedLightTheme = EditorView.theme({
    '&': {
        color: '#586e75',
        backgroundColor: '#fdf6e3',
        '& ::selection': { backgroundColor: '#eee8d5' },
        caretColor: '#657b83',
    },
    '&.cm-focused .cm-cursor': { borderLeftColor: '#657b83' },
    '&.cm-focused .cm-selectionBackground, .cm-selectionBackground': { backgroundColor: '#eee8d5' },
    '.cm-panels': { backgroundColor: '#eee8d5', color: '#586e75' },
    '.cm-panels.cm-panels-top': { borderBottom: '2px solid black' },
    '.cm-panels.cm-panels-bottom': { borderTop: '2px solid black' },
    '.cm-searchMatch': {
        backgroundColor: '#eee8d5',
        outline: `1px solid #d3af86`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: '#eee8d5'
    },
    '.cm-activeLine': { backgroundColor: '#eee8d5' },
    '.cm-selectionMatch': { backgroundColor: '#eee8d5' },
    '.cm-matchingBracket, .cm-nonmatchingBracket': {
        backgroundColor: '',
        outline: 'none'
    },
    '.cm-gutters': {
        backgroundColor: '#fdf6e3',
        color: '#586e75',
        border: 'none'
    },
    '.cm-lineNumbers, .cm-gutterElement': { color: 'inherit' },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: '#586e75'
    },
    '.cm-tooltip': {
        border: '1px solid #d3af86',
        backgroundColor: '#eee8d5'
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: '#eee8d5',
            color: '#586e75'
        }
    }
}, { dark: false });
const solarizedLightHighlightStyle = HighlightStyle.define([
    // const, let, function, if
    { tag: tags.keyword, color: '#859900' },
    // document
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: '#657b83' },
    // getElementById
    { tag: [tags.propertyName], color: '#268BD2' },
    // "string"
    { tag: [tags.processingInstruction, tags.string, tags.inserted, tags.special(tags.string)], color: '#2AA198' },
    // render
    { tag: [tags.function(tags.variableName), tags.labelName], color: '#268BD2' },
    // ???
    { tag: [tags.color, tags.constant(tags.name), tags.standard(tags.name)], color: '#CB4B16' },
    // btn, count, fn render()
    { tag: [tags.definition(tags.name), tags.separator], color: '#657b83' },
    { tag: [tags.className], color: '#268BD2' },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: '#D33682' },
    { tag: [tags.typeName], color: '#859900', fontStyle: '' },
    { tag: [tags.operator, tags.operatorKeyword], color: '#859900' },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: '#D30102' },
    { tag: [tags.meta, tags.comment], color: '#93A1A1' },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: '#268BD2' },
    { tag: [tags.atom, tags.bool, tags.special(tags.variableName)], color: '#657b83' },
    { tag: tags.invalid, color: '' },
]);
const solarizedLight = [
    solarizedLightTheme,
    solarizedLightHighlightStyle,
];

export { solarizedLight, solarizedLightHighlightStyle, solarizedLightTheme };
